@@ -27,7 +27,9 @@ class TioneClient(AbstractClient):
 
 
     def ChatCompletion(self, request):
-        """与大模型聊天
+        """该接口支持与两种类型大模型的聊天。
+        1. 与多行业多场景大模型的在线体验聊天
+        2. 与自行部署的开源大模型的聊天
 
         :param request: Request instance for ChatCompletion.
         :type request: :class:`tencentcloud.tione.v20211111.models.ChatCompletionRequest`
@@ -625,7 +627,7 @@ class TioneClient(AbstractClient):
 
 
     def DescribeBillingSpecsPrice(self, request):
-        """本接口(DescribeBillingSpecsPrice)用于查询计费项价格。
+        """本接口(DescribeBillingSpecsPrice)用于查询按量计费计费项价格。
 
         :param request: Request instance for DescribeBillingSpecsPrice.
         :type request: :class:`tencentcloud.tione.v20211111.models.DescribeBillingSpecsPriceRequest`
@@ -763,7 +765,7 @@ class TioneClient(AbstractClient):
 
 
     def DescribeLogs(self, request):
-        """获取训练、推理、Notebook服务的日志
+        """获取训练、推理、Notebook服务的日志 API
 
         :param request: Request instance for DescribeLogs.
         :type request: :class:`tencentcloud.tione.v20211111.models.DescribeLogsRequest`
@@ -1452,6 +1454,29 @@ class TioneClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def SendChatMessage(self, request):
+        """这是一个供您体验大模型聊天的接口。
+
+        :param request: Request instance for SendChatMessage.
+        :type request: :class:`tencentcloud.tione.v20211111.models.SendChatMessageRequest`
+        :rtype: :class:`tencentcloud.tione.v20211111.models.SendChatMessageResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("SendChatMessage", params, headers=headers)
+            response = json.loads(body)
+            model = models.SendChatMessageResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def StartNotebook(self, request):
         """启动Notebook
 
